import { createIconBase } from '../createIcon.js';

export const OutlinedMinusSquareIconConfig = {
  name: 'OutlinedMinusSquareIcon',
  icon: {"xOffset":0,"yOffset":0,"width":448,"height":512,"svgPathData":"M108 284c-6.6 0-12-5.4-12-12v-32c0-6.6 5.4-12 12-12h232c6.6 0 12 5.4 12 12v32c0 6.6-5.4 12-12 12H108zM448 80v352c0 26.5-21.5 48-48 48H48c-26.5 0-48-21.5-48-48V80c0-26.5 21.5-48 48-48h352c26.5 0 48 21.5 48 48zm-48 346V86c0-3.3-2.7-6-6-6H54c-3.3 0-6 2.7-6 6v340c0 3.3 2.7 6 6 6h340c3.3 0 6-2.7 6-6z"},
  rhUiIcon: null,
};

export const OutlinedMinusSquareIcon = createIconBase(OutlinedMinusSquareIconConfig);

export default OutlinedMinusSquareIcon;