import { createIconBase } from '../createIcon.js';

export const RhUiServerIconConfig = {
  name: 'RhUiServerIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M29.5 9h-27C1.673 9 1 9.673 1 10.5v11c0 .827.673 1.5 1.5 1.5h27c.827 0 1.5-.673 1.5-1.5v-11c0-.827-.673-1.5-1.5-1.5ZM29 21H3V11h26v10ZM7 16a1 1 0 0 1 1-1h5a1 1 0 0 1 0 2H8a1 1 0 0 1-1-1Zm14.38.015a1.626 1.626 0 1 1 3.251.001 1.626 1.626 0 0 1-3.251-.001Z"},
  rhUiIcon: null,
};

export const RhUiServerIcon = createIconBase(RhUiServerIconConfig);

export default RhUiServerIcon;