import { createIconBase } from '../createIcon.js';

export const RhStandardHarveyBall70IconConfig = {
  name: 'RhStandardHarveyBall70Icon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M18 3.375A14.625 14.625 0 1 0 32.625 18 14.642 14.642 0 0 0 18 3.375Zm-.625 1.282v12.89l-12.214 4.17a13.331 13.331 0 0 1 12.214-17.06Z"},
  rhUiIcon: null,
};

export const RhStandardHarveyBall70Icon = createIconBase(RhStandardHarveyBall70IconConfig);

export default RhStandardHarveyBall70Icon;