import { createIconBase } from '../createIcon.js';

export const RhUiDuplicateIconConfig = {
  name: 'RhUiDuplicateIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M28.5 12h-15c-.827 0-1.5.673-1.5 1.5v15c0 .827.673 1.5 1.5 1.5h15c.827 0 1.5-.673 1.5-1.5v-15c0-.827-.673-1.5-1.5-1.5ZM28 28H14V14h14v14ZM9 19a1 1 0 0 1-1 1H3.5c-.827 0-1.5-.673-1.5-1.5v-15C2 2.673 2.673 2 3.5 2h15c.827 0 1.5.673 1.5 1.5V8a1 1 0 0 1-2 0V4H4v14h4a1 1 0 0 1 1 1Z"},
  rhUiIcon: null,
};

export const RhUiDuplicateIcon = createIconBase(RhUiDuplicateIconConfig);

export default RhUiDuplicateIcon;