export interface SampleDataRow {
  name: string;
  threads: number;
  applications: number;
  workspaces: number;
  lastModified: string;
  url: string;
}

export const columns = ['Servers', 'Threads', 'Applications', 'Workspaces', 'Last Modified', 'URL'];

export const rows: SampleDataRow[] = [
  {
    name: 'patternfly',
    threads: 12,
    applications: 34,
    workspaces: 22,
    lastModified: '2 hours ago',
    url: 'http://www.redhat.com/en/office-locations/US-node1'
  },
  {
    name: 'patternfly-elements',
    threads: 7,
    applications: 42,
    workspaces: 18,
    lastModified: '5 hours ago',
    url: 'http://www.redhat.com/en/office-locations/US-node2'
  },
  {
    name: 'patternfly-unified-design-kit',
    threads: 5,
    applications: 25,
    workspaces: 10,
    lastModified: '20 minutes ago',
    url: 'http://www.redhat.com/en/office-locations/US-node3'
  },
  {
    name: 'patternfly-elements',
    threads: 19,
    applications: 36,
    workspaces: 21,
    lastModified: '10 minutes ago',
    url: 'http://www.redhat.com/en/office-locations/US-node4'
  },
  {
    name: 'patternfly',
    threads: 8,
    applications: 49,
    workspaces: 17,
    lastModified: '15 minutes ago',
    url: 'http://www.redhat.com/en/office-locations/US-node5'
  },
  {
    name: 'patternfly-unified-design-kit',
    threads: 3,
    applications: 12,
    workspaces: 26,
    lastModified: '4 hours ago',
    url: 'http://www.redhat.com/en/office-locations/US-node6'
  },
  {
    name: 'patternfly-elements',
    threads: 14,
    applications: 22,
    workspaces: 5,
    lastModified: '10 minutes ago',
    url: 'http://www.redhat.com/en/office-locations/US-node7'
  },
  {
    name: 'patternfly',
    threads: 11,
    applications: 31,
    workspaces: 24,
    lastModified: '8 hours ago',
    url: 'http://www.redhat.com/en/office-locations/US-node8'
  },
  {
    name: 'patternfly-unified-design-kit',
    threads: 4,
    applications: 19,
    workspaces: 9,
    lastModified: '1 hour ago',
    url: 'http://www.redhat.com/en/office-locations/US-node9'
  },
  {
    name: 'patternfly-elements',
    threads: 18,
    applications: 47,
    workspaces: 14,
    lastModified: '2 hours ago',
    url: 'http://www.redhat.com/en/office-locations/US-node10'
  },
  {
    name: 'patternfly',
    threads: 1,
    applications: 38,
    workspaces: 29,
    lastModified: '55 minutes ago',
    url: 'http://www.redhat.com/en/office-locations/US-node11'
  },
  {
    name: 'patternfly-unified-design-kit',
    threads: 9,
    applications: 27,
    workspaces: 16,
    lastModified: '1 hour ago',
    url: 'http://www.redhat.com/en/office-locations/US-node12'
  },
  {
    name: 'patternfly-elements',
    threads: 16,
    applications: 41,
    workspaces: 3,
    lastModified: '20 minutes ago',
    url: 'http://www.redhat.com/en/office-locations/US-node13'
  },
  {
    name: 'patternfly',
    threads: 2,
    applications: 15,
    workspaces: 28,
    lastModified: '4 hours ago',
    url: 'http://www.redhat.com/en/office-locations/US-node14'
  },
  {
    name: 'patternfly-unified-design-kit',
    threads: 20,
    applications: 33,
    workspaces: 11,
    lastModified: '10 minutes ago',
    url: 'http://www.redhat.com/en/office-locations/US-node15'
  },
  {
    name: 'patternfly-elements',
    threads: 13,
    applications: 44,
    workspaces: 7,
    lastModified: '5 minutes ago',
    url: 'http://www.redhat.com/en/office-locations/US-node16'
  },
  {
    name: 'patternfly',
    threads: 6,
    applications: 29,
    workspaces: 25,
    lastModified: '5 hours ago',
    url: 'http://www.redhat.com/en/office-locations/US-node17'
  },
  {
    name: 'patternfly-unified-design-kit',
    threads: 10,
    applications: 17,
    workspaces: 20,
    lastModified: '10 minutes ago',
    url: 'http://www.redhat.com/en/office-locations/US-node18'
  },
  {
    name: 'patternfly-elements',
    threads: 15,
    applications: 50,
    workspaces: 8,
    lastModified: '30 minutes ago',
    url: 'http://www.redhat.com/en/office-locations/US-node19'
  },
  {
    name: 'patternfly',
    threads: 17,
    applications: 23,
    workspaces: 27,
    lastModified: '3 hours ago',
    url: 'http://www.redhat.com/en/office-locations/US-node20'
  },
  {
    name: 'patternfly-unified-design-kit',
    threads: 7,
    applications: 39,
    workspaces: 19,
    lastModified: '15 minutes ago',
    url: 'http://www.redhat.com/en/office-locations/US-node21'
  },
  {
    name: 'patternfly-elements',
    threads: 11,
    applications: 16,
    workspaces: 6,
    lastModified: '2 hours ago',
    url: 'http://www.redhat.com/en/office-locations/US-node22'
  },
  {
    name: 'patternfly',
    threads: 5,
    applications: 37,
    workspaces: 30,
    lastModified: '2 hours ago',
    url: 'http://www.redhat.com/en/office-locations/US-node23'
  },
  {
    name: 'patternfly-unified-design-kit',
    threads: 9,
    applications: 28,
    workspaces: 12,
    lastModified: '40 minutes ago',
    url: 'http://www.redhat.com/en/office-locations/US-node24'
  },
  {
    name: 'patternfly-elements',
    threads: 14,
    applications: 46,
    workspaces: 4,
    lastModified: '1 hour ago',
    url: 'http://www.redhat.com/en/office-locations/US-node25'
  },
  {
    name: 'patternfly',
    threads: 3,
    applications: 21,
    workspaces: 23,
    lastModified: '2 hours ago',
    url: 'http://www.redhat.com/en/office-locations/US-node26'
  },
  {
    name: 'patternfly-unified-design-kit',
    threads: 8,
    applications: 32,
    workspaces: 13,
    lastModified: '7 hours ago',
    url: 'http://www.redhat.com/en/office-locations/CZ-node1'
  },
  {
    name: 'patternfly-elements',
    threads: 20,
    applications: 11,
    workspaces: 2,
    lastModified: '50 minutes ago',
    url: 'http://www.redhat.com/en/office-locations/CZ-node2'
  },
  {
    name: 'patternfly',
    threads: 12,
    applications: 48,
    workspaces: 22,
    lastModified: '10 minutes ago',
    url: 'http://www.redhat.com/en/office-locations/CZ-node3'
  },
  {
    name: 'patternfly-unified-design-kit',
    threads: 6,
    applications: 26,
    workspaces: 15,
    lastModified: '3 hours ago',
    url: 'http://www.redhat.com/en/office-locations/CZ-node4'
  },
  {
    name: 'patternfly-elements',
    threads: 19,
    applications: 43,
    workspaces: 9,
    lastModified: '2 hours ago',
    url: 'http://www.redhat.com/en/office-locations/CZ-node5'
  },
  {
    name: 'patternfly',
    threads: 2,
    applications: 18,
    workspaces: 29,
    lastModified: '2 hours ago',
    url: 'http://www.redhat.com/en/office-locations/CZ-node6'
  },
  {
    name: 'patternfly-unified-design-kit',
    threads: 15,
    applications: 35,
    workspaces: 14,
    lastModified: '25 minutes ago',
    url: 'http://www.redhat.com/en/office-locations/CZ-node7'
  },
  {
    name: 'patternfly-elements',
    threads: 10,
    applications: 45,
    workspaces: 7,
    lastModified: '1 hour ago',
    url: 'http://www.redhat.com/en/office-locations/CZ-node8'
  },
  {
    name: 'patternfly',
    threads: 4,
    applications: 20,
    workspaces: 24,
    lastModified: '15 minutes ago',
    url: 'http://www.redhat.com/en/office-locations/CZ-node9'
  },
  {
    name: 'patternfly-unified-design-kit',
    threads: 13,
    applications: 30,
    workspaces: 17,
    lastModified: '3 hours ago',
    url: 'http://www.redhat.com/en/office-locations/CZ-node10'
  },
  {
    name: 'patternfly-elements',
    threads: 18,
    applications: 40,
    workspaces: 1,
    lastModified: '30 minutes ago',
    url: 'http://www.redhat.com/en/office-locations/CZ-node11'
  },
  {
    name: 'patternfly',
    threads: 1,
    applications: 13,
    workspaces: 26,
    lastModified: '5 minutes ago',
    url: 'http://www.redhat.com/en/office-locations/CZ-node12'
  },
  {
    name: 'patternfly-unified-design-kit',
    threads: 16,
    applications: 24,
    workspaces: 11,
    lastModified: '45 minutes ago',
    url: 'http://www.redhat.com/en/office-locations/CZ-node13'
  },
  {
    name: 'patternfly-elements',
    threads: 8,
    applications: 49,
    workspaces: 3,
    lastModified: '2 hours ago',
    url: 'http://www.redhat.com/en/office-locations/CZ-node14'
  },
  {
    name: 'patternfly',
    threads: 7,
    applications: 14,
    workspaces: 28,
    lastModified: '10 minutes ago',
    url: 'http://www.redhat.com/en/office-locations/CZ-node15'
  },
  {
    name: 'patternfly-unified-design-kit',
    threads: 14,
    applications: 33,
    workspaces: 20,
    lastModified: '20 minutes ago',
    url: 'http://www.redhat.com/en/office-locations/CZ-Remote-node1'
  },
  {
    name: 'patternfly-elements',
    threads: 3,
    applications: 47,
    workspaces: 8,
    lastModified: '15 minutes ago',
    url: 'http://www.redhat.com/en/office-locations/CZ-Remote-node2'
  },
  {
    name: 'patternfly',
    threads: 11,
    applications: 19,
    workspaces: 25,
    lastModified: '2 hours ago',
    url: 'http://www.redhat.com/en/office-locations/CZ-Remote-node3'
  },
  {
    name: 'patternfly-unified-design-kit',
    threads: 5,
    applications: 31,
    workspaces: 13,
    lastModified: '1 hour ago',
    url: 'http://www.redhat.com/en/office-locations/CZ-Remote-node4'
  },
  {
    name: 'patternfly-elements',
    threads: 17,
    applications: 50,
    workspaces: 6,
    lastModified: '30 minutes ago',
    url: 'http://www.redhat.com/en/office-locations/CZ-Remote-node5'
  },
  {
    name: 'patternfly',
    threads: 9,
    applications: 22,
    workspaces: 21,
    lastModified: '2 hours ago',
    url: 'http://www.redhat.com/en/office-locations/CZ-Remote-node6'
  },
  {
    name: 'patternfly-unified-design-kit',
    threads: 2,
    applications: 37,
    workspaces: 18,
    lastModified: '45 minutes ago',
    url: 'http://www.redhat.com/en/office-locations/CZ-remote-node7'
  },
  {
    name: 'patternfly-elements',
    threads: 19,
    applications: 41,
    workspaces: 4,
    lastModified: '6 hours ago',
    url: 'http://www.redhat.com/en/office-locations/CZ-remote-node8'
  },
  {
    name: 'patternfly',
    threads: 13,
    applications: 15,
    workspaces: 27,
    lastModified: '50 minutes ago',
    url: 'http://www.redhat.com/en/office-locations/CZ-remote-node9'
  },
  {
    name: 'patternfly-unified-design-kit',
    threads: 4,
    applications: 29,
    workspaces: 16,
    lastModified: '3 hours ago',
    url: 'http://www.redhat.com/en/office-locations/CZ-remote-node10'
  },
  {
    name: 'patternfly-elements',
    threads: 20,
    applications: 46,
    workspaces: 10,
    lastModified: '2 hours ago',
    url: 'http://www.redhat.com/en/office-locations/CZ-remote-node11'
  },
  {
    name: 'patternfly',
    threads: 6,
    applications: 12,
    workspaces: 23,
    lastModified: '20 minutes ago',
    url: 'http://www.redhat.com/en/office-locations/CZ-remote-node12'
  },
  {
    name: 'patternfly-unified-design-kit',
    threads: 10,
    applications: 25,
    workspaces: 19,
    lastModified: '5 hours ago',
    url: 'http://www.redhat.com/en/office-locations/CZ-remote-node13'
  },
  {
    name: 'patternfly-elements',
    threads: 7,
    applications: 38,
    workspaces: 5,
    lastModified: '30 minutes ago',
    url: 'http://www.redhat.com/en/office-locations/CZ-remote-node14'
  },
  {
    name: 'patternfly',
    threads: 16,
    applications: 17,
    workspaces: 30,
    lastModified: '1 hour ago',
    url: 'http://www.redhat.com/en/office-locations/CZ-remote-node15'
  },
  {
    name: 'patternfly-unified-design-kit',
    threads: 12,
    applications: 36,
    workspaces: 15,
    lastModified: '1 hour ago',
    url: 'http://www.redhat.com/en/office-locations/CZ-remote-node16'
  },
  {
    name: 'patternfly-elements',
    threads: 5,
    applications: 44,
    workspaces: 2,
    lastModified: '25 minutes ago',
    url: 'http://www.redhat.com/en/office-locations/CZ-remote-node17'
  },
  {
    name: 'patternfly',
    threads: 18,
    applications: 21,
    workspaces: 22,
    lastModified: '20 minutes ago',
    url: 'http://www.redhat.com/en/office-locations/CZ-remote-node18'
  },
  {
    name: 'patternfly-unified-design-kit',
    threads: 9,
    applications: 32,
    workspaces: 12,
    lastModified: '25 minutes ago',
    url: 'http://www.redhat.com/en/office-locations/Bangalore-node1'
  },
  {
    name: 'patternfly-elements',
    threads: 3,
    applications: 43,
    workspaces: 7,
    lastModified: '2 hours ago',
    url: 'http://www.redhat.com/en/office-locations/Bangalore-node2'
  },
  {
    name: 'patternfly',
    threads: 15,
    applications: 18,
    workspaces: 24,
    lastModified: '10 minutes ago',
    url: 'http://www.redhat.com/en/office-locations/Bangalore-node3'
  },
  {
    name: 'patternfly-unified-design-kit',
    threads: 8,
    applications: 27,
    workspaces: 14,
    lastModified: '50 minutes ago',
    url: 'http://www.redhat.com/en/office-locations/Bangalore-node4'
  },
  {
    name: 'patternfly-elements',
    threads: 1,
    applications: 47,
    workspaces: 9,
    lastModified: '3 hours ago',
    url: 'http://www.redhat.com/en/office-locations/Bangalore-node5'
  },
  {
    name: 'patternfly',
    threads: 13,
    applications: 23,
    workspaces: 28,
    lastModified: '2 hours ago',
    url: 'http://www.redhat.com/en/office-locations/Bangalore-node6'
  },
  {
    name: 'patternfly-unified-design-kit',
    threads: 6,
    applications: 34,
    workspaces: 17,
    lastModified: '5 hours ago',
    url: 'http://www.redhat.com/en/office-locations/Bangalore-node7'
  },
  {
    name: 'patternfly-elements',
    threads: 20,
    applications: 39,
    workspaces: 3,
    lastModified: '30 minutes ago',
    url: 'http://www.redhat.com/en/office-locations/Bangalore-node8'
  },
  {
    name: 'patternfly',
    threads: 4,
    applications: 14,
    workspaces: 26,
    lastModified: '20 minutes ago',
    url: 'http://www.redhat.com/en/office-locations/Bangalore-node9'
  },
  {
    name: 'patternfly-unified-design-kit',
    threads: 17,
    applications: 28,
    workspaces: 11,
    lastModified: '1 hour ago',
    url: 'http://www.redhat.com/en/office-locations/Bangalore-node10'
  },
  {
    name: 'patternfly-elements',
    threads: 11,
    applications: 42,
    workspaces: 8,
    lastModified: '40 minutes ago',
    url: 'http://www.redhat.com/en/office-locations/Bangalore-node11'
  },
  {
    name: 'patternfly',
    threads: 2,
    applications: 19,
    workspaces: 25,
    lastModified: '1 hour ago',
    url: 'http://www.redhat.com/en/office-locations/Bangalore-node12'
  },
  {
    name: 'patternfly-unified-design-kit',
    threads: 14,
    applications: 30,
    workspaces: 13,
    lastModified: '20 minutes ago',
    url: 'http://www.redhat.com/en/office-locations/Bangalore-node13'
  },
  {
    name: 'patternfly-elements',
    threads: 10,
    applications: 45,
    workspaces: 1,
    lastModified: '4 hours ago',
    url: 'http://www.redhat.com/en/office-locations/Bangalore-node14'
  },
  {
    name: 'patternfly',
    threads: 7,
    applications: 16,
    workspaces: 27,
    lastModified: '2 hours ago',
    url: 'http://www.redhat.com/en/office-locations/Bangalore-node15'
  },
  {
    name: 'patternfly-unified-design-kit',
    threads: 19,
    applications: 31,
    workspaces: 20,
    lastModified: '3 hours ago',
    url: 'http://www.redhat.com/en/office-locations/Bangalore-node16'
  }
];
